@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# Copyright (c) 2010-2022 Sullivan Beck.  All rights reserved.
+# Copyright (c) 2010-2023 Sullivan Beck.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -14,11 +14,10 @@ $Data{'language'}{'link'} =
 ################################################################################
 
 $Data{'language'}{'iso2'}{'orig'}{'name'} = {
-   "Bokm\x{e5}l, Norwegian"           => 'Bokmal, Norwegian',
-   "Norwegian Bokm\x{e5}l"            => 'Norwegian Bokmal',
-   "Proven\x{e7}al"                   => 'Provencal',
-   "Proven\x{e7}al, Old (to 1500)"    => 'Provencal, Old (to 1500)',
-   "Volap\x{fc}k"                     => 'Volapuk',
+   "Bokmål, Norwegian"               => 'Bokmal, Norwegian',
+   "Norwegian Bokmål"                => 'Norwegian Bokmal',
+   "Provençal, Old (to 1500)"       => 'Provencal, Old (to 1500)',
+   "Volapük"                        => 'Volapuk',
 };
 
 $Data{'language'}{'iso2'}{'ignore'} = {
@@ -513,6 +512,7 @@ $Data{'language'}{'iana'}{'orig'}{'name'} = {
    "Juǀʼhoansi"                                    => "Ju|'hoansi",
    "Meänkieli"                                      => "Meankieli",
    "Lengua de señas Albarradas"                     => "Lengua de senas Albarradas",
+   "Língua Gestual Guineense"                      => "Lingua Gestual Guineense",
 };
 
 $Data{'language'}{'iana'}{'ignore'} = {
